cotede.ProfileQC
================

.. currentmodule:: cotede

.. autoclass:: ProfileQC


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~ProfileQC.__init__
      ~ProfileQC.keys


   .. rubric:: Attributes

   .. autosummary::

      ~ProfileQC.attrs
      ~ProfileQC.features
